@@ -41,11 +41,12 @@ API Specification
 -----------------
 
 .. autoclass:: NagAconda.Plugin
-   :members: add_option, enable_status, finish, set_value, start
+   :members: add_option, enable_status, finish, set_value, set_status_message,
+             start, unknown_error
 
 """
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 __all__ = ['Plugin']
 
 # We need the option parser primarily to provide an instruction harness to the
